#! /usr/bin/pyton

class GpioEmu(object):
    HIGH = 1
    LOW = 0
    IN = 10
    OUT = 11
    BOARD = 20
    BCM = 21
    RISING = 30
    FALLING = 31
    BOTH = 32
    
    @classmethod
    def setmode(cls, mode):
        print("setmode {}".format(mode))

    @classmethod
    def setup(cls,port, mode):
        print("setup {} {}".format(port, mode))

    @classmethod
    def input(cls, port):
        print("input {}".format(port))
        return cls.HIGH

    @classmethod
    def output(cls, port, state):
        print("output {} {}".format(port, state))

    @classmethod
    def cleanup(cls, channels=None):
        print("cleanup {}".format(channels))

    @classmethod
    def wait_for_edge(cls, channel, edge, timeout=1000):
        print("wait_for_edge {} {} {}".format(channel, edge, timeout))
        ret = random.choice([True, False, None])
        if ret is None:
            time.sleep(timeout/1000.0)
        return ret

    @classmethod
    def add_event_detect(cls, channel, edge, callback=None, bouncetime=None):
        print("add_event_detect {} {} {} {}".format(channel, edge, callback, bouncetime))

    @classmethod
    def event_detected(cls, channel):
        print ("event_dectected {}".format(channel))
        return random.choice([True, False])

    @classmethod
    def remove_event_detect(cls, channel):
        print("remove_event_detect {}".format(channel))

try:
    from RPi import GPIO as _gpio
except ImportError:
    _gpio = GpioEmu()


class AntennaSwitch(object):

    h0 = 17
    h1 = 27
    h2 = 22
    nen = 10

    def __init__(self):
        self._init_done = False

    def __enter__(self):
       self.open()
       return self


    def open(self):
       _gpio.setmode(_gpio.BCM)
       _gpio.setup(self.h0,_gpio.OUT)
       _gpio.setup(self.h1,_gpio.OUT)
       _gpio.setup(self.h2,_gpio.OUT)
       _gpio.setup(self.nen,_gpio.OUT)
       self.off()
       self._init_done = True

    def __exit__(self, exc_type, exc_value, traceback):
        self.close()

    def close(self):
        self.off()
        self._init_done = True
        _gpio.cleanup()
  
    def on(self):
        _gpio.output(self.nen, _gpio.LOW)

    def off(self):
        _gpio.output(self.nen, _gpio.HIGH)

    def set_antenna(self, ant_number):
        if ant_number >= 0 and ant_number < 8:
            b0 = ant_number & 0x1
            b1 = ant_number & 0x2
            b2 = ant_number & 0x4
            _gpio.output(self.h0, _gpio.HIGH if b0 else _gpio.LOW)
            _gpio.output(self.h1, _gpio.HIGH if b1 else _gpio.LOW)
            _gpio.output(self.h2, _gpio.HIGH if b2 else _gpio.LOW)
